==============
Database faker
==============


.. image:: https://img.shields.io/pypi/v/db-faker.svg
        :target: https://pypi.python.org/pypi/db-faker

.. image:: https://circleci.com/gh/PBarri/db-faker.svg?style=shield
        :target: https://app.circleci.com/pipelines/github/PBarri/db-faker

.. image:: https://sonarcloud.io/api/project_badges/measure?project=PBarri_db-faker&metric=alert_status
        :target: https://sonarcloud.io/dashboard?id=PBarri_db-faker

.. image:: https://sonarcloud.io/api/project_badges/measure?project=PBarri_db-faker&metric=security_rating
        :target: https://sonarcloud.io/dashboard?id=PBarri_db-faker

.. image:: https://sonarcloud.io/api/project_badges/measure?project=PBarri_db-faker&metric=reliability_rating
        :target: https://sonarcloud.io/dashboard?id=PBarri_db-faker

.. image:: https://sonarcloud.io/api/project_badges/measure?project=PBarri_db-faker&metric=sqale_rating
        :target: https://sonarcloud.io/dashboard?id=PBarri_db-faker

.. image:: https://readthedocs.org/projects/db-faker/badge/?version=latest
        :target: https://db-faker.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



CLI application that handles the creation of fake data for test databases.

* Free software: MIT license
* Documentation: https://db-faker.readthedocs.io.


Features
--------

* Creation of fake data from a JSON schema defining the database structure.
* Extensible outputs. Console and File outputs available from the box.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
